@@ -1,19 +1,19 @@
 #' Public holidays in Japan
 #' @description
 #' \Sexpr[results=rd, stage=render]{lifecycle::badge("experimental")}
-#' @details Holiday information refers to data published as of January 1, 2020.
+#' @details Holiday information refers to data published as of December 21, 2020.
 #' Future holidays are subject to change.
 #' @param year numeric year and in and after 1949.
 #' @param name holiday name
 #' @param lang return holiday names to "en" or "jp".
 #' @references Public Holiday Law [https://www8.cao.go.jp/chosei/shukujitsu/gaiyou.html](https://www8.cao.go.jp/chosei/shukujitsu/gaiyou.html),
-#' [https://elaws.e-gov.go.jp/search/elawsSearch/elaws_search/lsg0500/detail?lawId=323AC1000000178](https://elaws.e-gov.go.jp/search/elawsSearch/elaws_search/lsg0500/detail?lawId=323AC1000000178)
+#' [https://elaws.e-gov.go.jp/document?lawid=323AC1000000178](https://elaws.e-gov.go.jp/document?lawid=323AC1000000178)
 #' @rdname jholiday
 #' @examples
 #' jholiday_spec(2019, "Sports Day")
-#' jholiday_spec(2020, "Sports Day")
+#' jholiday_spec(2021, "Sports Day")
 #' # List of a specific year holidays
-#' jholiday(2020, "en")
+#' jholiday(2021, "en")
 #' @export
 jholiday_spec <- function(year, name, lang = "en") {
   jholiday_names <- jholiday_list[[lang]]
@@ -61,14 +61,18 @@ jholiday_spec <- function(year, name, lang = "en") {
       # Marine Day
       name == jholiday_names[12] & year == 2020 ~
         lubridate::as_date("20200723"),
-      name == jholiday_names[12] & year >= 2003 & year != 2020 ~
+      name == jholiday_names[12] & year == 2021 ~
+        lubridate::as_date("20210722"),
+      name == jholiday_names[12] & year >= 2003 & year != 2020 & year != 2021 ~
         find_date_by_wday(year, 7, 2, 3),
       name == jholiday_names[12] & dplyr::between(year, 1996, 2002) ~
         lubridate::make_date(year, 7, 20),
       # Mountain Day
       name == jholiday_names[13] & year == 2020 ~
         lubridate::as_date("20200810"),
-      name == jholiday_names[13] & year >= 2016 & year != 2020 ~
+      name == jholiday_names[13] & year == 2021 ~
+        lubridate::as_date("20210808"),
+      name == jholiday_names[13] & year >= 2016 & year != 2020 & year != 2021 ~
         lubridate::make_date(year, 8, 11),
       # Respect for the Aged Day
       name == jholiday_names[14] & dplyr::between(year, 1966, 2002) ~
@@ -81,9 +85,13 @@ jholiday_spec <- function(year, name, lang = "en") {
       # Sports Day
       name == jholiday_names[17] & year == 2020 ~
         lubridate::as_date("20200724"),
-        name %in% jholiday_names[16:17] & year >= 2000 & year != 2020 ~
+      name == jholiday_names[17] & year == 2021 ~
+        lubridate::as_date("20210723"),
+      name %in% jholiday_names[16] & dplyr::between(year, 2000, 2019) ~
           find_date_by_wday(year, 10, 2, 2),
-      name %in% jholiday_names[16:17] & dplyr::between(year, 1966, 1999) ~
+      name %in% jholiday_names[17] & year >= 2022 ~
+          find_date_by_wday(year, 10, 2, 2),
+      name %in% jholiday_names[16] & dplyr::between(year, 1966, 1999) ~
         lubridate::make_date(year, 10, 10),
       # Culture Day
       name == jholiday_names[18] ~
@@ -168,13 +176,13 @@ shubun_day <- function(year) {
 #' @description
 #' \Sexpr[results=rd, stage=render]{lifecycle::badge("experimental")}
 #' Whether it is a holiday defined by Japanese law (enacted in 1948)
-#' @details Holiday information refers to data published as of January 1, 2020.
+#' @details Holiday information refers to data published as of December 21, 2020.
 #' Future holidays are subject to change.
 #' @param date a vector of [POSIXt], numeric or character objects
 #' @return TRUE if x is a public holidays in Japan, FALSE otherwise.
 #' @rdname is_jholiday
 #' @examples
-#' is_jholiday("2020-01-01")
+#' is_jholiday("2021-01-01")
 #' is_jholiday("2018-12-23") # TRUE
 #' is_jholiday("2019-12-23") # FALSE
 #' @export
@@ -202,7 +210,7 @@ is_jholiday <- function(date) {
 #' @return a vector of class POSIXct
 #' @rdname find_date_by_wday
 #' @examples
-#' find_date_by_wday(2020, 1, 2, 2)
+#' find_date_by_wday(2021, 1, 2, 2)
 #' @export
 find_date_by_wday <- function(year, month, wday, ordinal) {
   date_begin <-
